@@ -7,7 +7,7 @@ use base 'Catalyst::Model::DBIC::Schema';
 __PACKAGE__->config(
     schema_class => 'MyAtom::Model::Schema',
     connect_info => [
-        'dbi:SQLite:dbname=atom.db',
+        'dbi:SQLite:dbname=test.db',
     ],
 );
 
